@@ -87,6 +87,7 @@ panel_frame_switcher_grab_focus (GtkWidget *widget)
   return FALSE;
 }
 
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 static void
 ensure_indicator (PanelFrameSwitcher *self)
 {
@@ -119,15 +120,15 @@ ensure_indicator (PanelFrameSwitcher *self)
   if (orientation == GTK_ORIENTATION_HORIZONTAL)
     {
       cairo_move_to (cr, INDICATOR_SIZE/2, 0);
-      cairo_line_to (cr, INDICATOR_SIZE/2, INDICATOR_SIZE-3);
+      cairo_line_to (cr, INDICATOR_SIZE/2, INDICATOR_SIZE/2);
       cairo_stroke (cr);
-      cairo_arc (cr, INDICATOR_SIZE/2-1, INDICATOR_SIZE-5, 4, 0, 2 * G_PI);
+      cairo_arc (cr, INDICATOR_SIZE/2, INDICATOR_SIZE-5, 4, 0, 2 * G_PI);
       cairo_fill (cr);
     }
   else
     {
       cairo_move_to (cr, 0, INDICATOR_SIZE/2);
-      cairo_line_to (cr, INDICATOR_SIZE-3, INDICATOR_SIZE/2);
+      cairo_line_to (cr, INDICATOR_SIZE/2, INDICATOR_SIZE/2);
       cairo_stroke (cr);
       cairo_arc (cr, INDICATOR_SIZE-5, INDICATOR_SIZE/2, 4, 0, 2 * G_PI);
       cairo_fill (cr);
@@ -137,6 +138,7 @@ ensure_indicator (PanelFrameSwitcher *self)
 
   self->drop_indicator = gtk_snapshot_free_to_node (snapshot);
 }
+G_GNUC_END_IGNORE_DEPRECATIONS
 
 static void
 panel_frame_switcher_init (PanelFrameSwitcher *switcher)
@@ -723,26 +725,27 @@ panel_frame_switcher_snapshot (GtkWidget   *widget,
 
   if (self->drop_before_button != NULL)
     {
-      GtkAllocation alloc;
+      graphene_rect_t alloc;
       gboolean is_first = gtk_widget_get_prev_sibling (self->drop_before_button) == NULL;
 
-      gtk_widget_get_allocation (self->drop_before_button, &alloc);
+      if (!gtk_widget_compute_bounds (GTK_WIDGET (self), self->drop_before_button, &alloc))
+        g_assert_not_reached ();
 
       if (orientation == GTK_ORIENTATION_HORIZONTAL)
         {
-          x = alloc.x - INDICATOR_SIZE/2;
-          y = alloc.y + alloc.height - INDICATOR_SIZE;
+          x = - alloc.origin.x - INDICATOR_SIZE - 3;
+          y = alloc.size.height - INDICATOR_SIZE - 3;
 
           if (is_first)
-            x += 4;
+            x += 3;
         }
       else
         {
-          x = alloc.x + alloc.width - INDICATOR_SIZE;
-          y = alloc.y - INDICATOR_SIZE/2;
+          x = alloc.size.width - INDICATOR_SIZE - 2;
+          y = - alloc.origin.y - INDICATOR_SIZE - 3;
 
           if (is_first)
-            y += 4;
+            y += 3;
         }
 
       draw_indicator = TRUE;
@@ -751,19 +754,20 @@ panel_frame_switcher_snapshot (GtkWidget   *widget,
            (frame = panel_frame_header_get_frame (PANEL_FRAME_HEADER (self))) &&
            _panel_frame_in_drop (frame))
     {
-      GtkAllocation alloc;
+      graphene_rect_t alloc;
 
-      gtk_widget_get_allocation (last, &alloc);
+      if (!gtk_widget_compute_bounds (GTK_WIDGET (self), last, &alloc))
+        g_assert_not_reached ();
 
       if (orientation == GTK_ORIENTATION_HORIZONTAL)
         {
-          x = alloc.x + alloc.width - INDICATOR_SIZE/2 - 4;
-          y = alloc.y + alloc.height - INDICATOR_SIZE;
+          x = alloc.size.width - INDICATOR_SIZE;
+          y = alloc.size.height - INDICATOR_SIZE - 3;
         }
       else
         {
-          x = alloc.x + alloc.width - INDICATOR_SIZE;
-          y = alloc.y + alloc.height - INDICATOR_SIZE/2 - 4;
+          x = alloc.size.width - INDICATOR_SIZE - 2;
+          y = alloc.size.height - INDICATOR_SIZE;
         }
 
       draw_indicator = TRUE;
